@@ -40,7 +40,13 @@ class Dynatrace:
         self.__open_third_party_events: Dict[str, int] = defaultdict(int)
 
     def get_entities(
-        self, entity_selector: str, time_from: str = "now-2h", time_to: str = "now", fields: Optional[str] = None, page_size=50
+        self,
+        entity_selector: str,
+        time_from: str = "now-2h",
+        time_to: str = "now",
+        fields: Optional[str] = None,
+        page_size=50,
+        threads=20,
     ) -> PaginatedList[Entity]:
         """
         Lists entities observed within the specified timeframe along with their properties.
@@ -119,7 +125,7 @@ class Dynatrace:
         :return: A list of monitored entities along with their properties.
         """
         params = {"pageSize": page_size, "entitySelector": entity_selector, "from": time_from, "to": time_to, "fields": fields}
-        return PaginatedList(Entity, self.__http_client, "/api/v2/entities", params, list_item="entities")
+        return PaginatedList(Entity, self.__http_client, "/api/v2/entities", params, list_item="entities", threads=20)
 
     def get_entity_types(self, page_size=50) -> PaginatedList[EntityType]:
         """
